@@ -1,6 +1,5 @@
 #!/usr/bin/python3
 
-from __future__ import annotations
 
 import json
 import os.path
@@ -19,7 +18,7 @@ try:
 except ImportError:
     pass
 
-from typing import TYPE_CHECKING
+from collections.abc import Callable
 
 import univention.testing.strings as uts
 import univention.testing.udm as udm_test
@@ -28,10 +27,6 @@ from ucsschool.importer.mass_import import user_import
 from univention.config_registry import ucr
 
 
-if TYPE_CHECKING:
-    from collections.abc import Callable
-
-
 CONNECTOR_WAIT_INTERVAL = 12
 CONNECTOR_WAIT_SLEEP = 5
 CONNECTOR_WAIT_TIME = CONNECTOR_WAIT_SLEEP * CONNECTOR_WAIT_INTERVAL
