@@ -14,7 +14,7 @@ from dockertest import tiny_app_apache
 DOCKER_APP_COUNT = 20
 
 
-@pytest.mark.skip()
+@pytest.mark.skip
 @pytest.mark.exposure('dangerous')
 def test_app_scaling(appcenter, app_name, app_version):
     apps = []
