@@ -68,7 +68,7 @@ fi
         app.add_to_local_appcenter()
         appcenter.update()
         app.install()
-        app.verify(joined=False)
+        app.verify()
         env = subprocess.check_output(f'univention-app shell {app_name} env', shell=True, text=True)
         assert 'TEST_KEY=1' in env, env
         subprocess.call(f'univention-app configure {app_name} --set TEST_KEY=2', shell=True)
